#
# spec file for package xmonad
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name xmonad
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           %{pkg_name}
Version:        0.18.0
Release:        1.14
Summary:        A tiling window manager
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
Source10:       xmonad.desktop
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-X11-devel
BuildRequires:  ghc-X11-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-data-default-class-devel
BuildRequires:  ghc-data-default-class-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-process-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-setlocale-devel
BuildRequires:  ghc-setlocale-prof
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-time-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unix-prof
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(xinerama)
Suggests:       ghc-xmonad-contrib-devel
Suggests:       ghc-xmonad-devel
# windowmanager is a generic provides for every WM - there are things (like Xvnc)
# That rely on the prsence of 'a WM', but do not care which one it is
Provides:       windowmanager
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-quickcheck-classes-devel
BuildRequires:  ghc-quickcheck-classes-prof
%endif

%description
Xmonad is a tiling window manager for X. Windows are arranged automatically to
tile the screen without gaps or overlap, maximising screen use. All features of
the window manager are accessible from the keyboard: a mouse is strictly
optional. xmonad is written and extensible in Haskell. Custom layout
algorithms, and other extensions, may be written by the user in config files.
Layouts are applied dynamically, and different layouts may be used on each
workspace. Xinerama is fully supported, allowing windows to be tiled on several
screens.

%package -n ghc-%{name}
Summary:        Haskell %{name} library

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.

%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Requires:       ghc-%{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}
install -m0644 -D man/xmonad.1 %{buildroot}%{_mandir}/man1/xmonad.1
gzip %{buildroot}%{_mandir}/man1/xmonad.1
%define desktop_src %{buildroot}%{_datadir}/xsessions/xmonad.desktop
install -m0644 -D %{SOURCE10} %{desktop_src}
%suse_update_desktop_file %{desktop_src}

%check
%cabal_test

%post -n ghc-%{name}-devel
%ghc_pkg_recache

%postun -n ghc-%{name}-devel
%ghc_pkg_recache

%files
%license LICENSE
%doc CHANGES.md README.md
%{_bindir}/%{name}
%{_mandir}/man1/xmonad.1%{?ext_man}
%{_datadir}/xsessions/xmonad.desktop

%files -n ghc-%{name} -f ghc-%{name}.files
%license LICENSE

%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%doc CHANGES.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sat Feb  3 2024 Peter Simons <psimons@suse.com>
- Update xmonad to version 0.18.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/xmonad-0.18.0/src/CHANGES.md
* Sun Apr  2 2023 Peter Simons <psimons@suse.com>
- Update xmonad to version 0.17.2.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/xmonad-0.17.2/src/CHANGES.md
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sat Nov  5 2022 Peter Simons <psimons@suse.com>
- Update xmonad to version 0.17.1 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Sep  3 2022 Peter Simons <psimons@suse.com>
- Update xmonad to version 0.17.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/xmonad-0.17.1/src/CHANGES.md
* Mon Nov  1 2021 psimons@suse.com
- Update xmonad to version 0.17.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/xmonad-0.17.0/src/CHANGES.md
* Wed Jun  2 2021 psimons@suse.com
- Update xmonad to version 0.15 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Thu Oct  4 2018 psimons@suse.com
- Update xmonad to version 0.15.
  [#]# 0.15 (September 30, 2018)
  * Reimplement `sendMessage` to deal properly with windowset changes made
    during handling.
  * Add new library functions `windowBracket` and `modifyWindowSet` to
    `XMonad.Operations`.
  [#]# 0.14.2 (August 21, 2018)
  [#]## Bug Fixes
  * Add the sample configuration file xmonad.hs again to the release tarball.
    [https://github.com/xmonad/xmonad/issues/181]
* Wed Aug 22 2018 psimons@suse.com
- Update xmonad to version 0.14.2.
  [#]# unknown (unknown)
  [#]# 0.14.1 (August 20, 2018)
  [#]## Breaking Changes
  * The cabal build no longer installs xmonad.hs, xmonad.1, and xmonad.1.html
    as data files. The location cabal picks for chose files isn't useful as
    standard tools like man(1) won't find them there. Instead, we rely on
    distributors to pick up the files from the source tarball during the build
    and to install them into proper locations where their users expect them.
    [https://github.com/xmonad/xmonad/pull/127]
  [#]## Bug Fixes
  * Add support for GHC 8.6.x by providing an instance for 'MonadFail X'. A
    side effect of that change is that our code no longer compiles with GHC
    versions prior to 8.0.x. We could work around that, no doubt, but the
    resulting code would require CPP and Cabal flags and whatnot. It feels more
    reasonable to just require a moderately recent compiler instead of going
    through all that trouble.
  * xmonad no longer always recompile on startup. Now it only does so if the
    executable does not have the name that would be used for the compilation
    output. The purpose of recompiling and executing the results in this case is
    so that the `xmonad` executable in the package can be used with custom
    configurations.
  [#]## Enhancements
  * Whenever xmonad recompiles, it now explains how it is attempting to
    recompile, by outputting logs to stderr. If you are using xmonad as a custom
    X session, then this will end up in a `.xsession-errors` file.
* Fri Aug 17 2018 psimons@suse.com
- Update Cabal build information to prevent build attempts with
  GHC 8.6.x.
* Tue Jul 31 2018 psimons@suse.com
- Add xmonad at version 0.14.
